<?php

/**
 * This is the model class for table "sod".
 *
 * The followings are the available columns in table 'sod':
 * @property string $sono
 * @property integer $sodno
 * @property string $taxid
 * @property string $deptid
 * @property string $srepid
 * @property string $prjid
 * @property string $whid
 * @property string $itemid
 * @property string $pid
 * @property string $itemdesc
 * @property string $qty
 * @property string $unit
 * @property string $conv
 * @property string $qtyx
 * @property string $qtydo
 * @property string $qtyxdo
 * @property string $qtydelivered
 * @property string $qtyxdelivered
 * @property string $qtybo
 * @property string $qtyxbo
 * @property string $cost
 * @property string $listprice
 * @property string $baseprice
 * @property string $discexp
 * @property string $discamt
 * @property string $disc2amt
 * @property string $taxamt
 * @property string $reqdate
 * @property string $sodnote
 * @property boolean $isclosed
 * @property string $subtotal
 * @property string $taxableamt
 * @property string $totaltaxamt
 * @property string $totaldiscamt
 * @property string $totaldisc2amt
 * @property string $basesubtotal
 * @property string $basetotaltaxamt
 * @property string $basftotaltaxamt
 * @property boolean $ispacked
 * @property boolean $iscancel
 *
 * The followings are the available model relations:
 * @property Delid[] $dels
 * @property Delid[] $dels1
 * @property Saled[] $saleds
 * @property Saled[] $saleds1
 * @property Dept $dept
 * @property Item $item
 * @property Prj $prj
 * @property So $so
 * @property Srep $srep
 * @property Tax $tax
 * @property Wh $wh
 * @property Deod[] $deods
 * @property Deod[] $deods1
 */
class Sod extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Sod the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'sod';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('itemid, itemdesc, qty, unit', 'required'),
            array('sodno', 'numerical', 'integerOnly' => true),
            array('sono, qty, conv, qtyx, qtydo, qtyxdo, qtydelivered, qtyxdelivered, qtybo, qtyxbo, discexp', 'length', 'max' => 15),
            array('taxid, deptid, prjid, unit', 'length', 'max' => 5),
            array('srepid', 'length', 'max' => 10),
            array('whid', 'length', 'max' => 3),
            array('itemid', 'length', 'max' => 20),
            array('pid', 'length', 'max' => 25),
            array('itemdesc', 'length', 'max' => 50),
            array('cost, listprice, baseprice, discamt, disc2amt, taxamt, subtotal, taxableamt, totaltaxamt, totaldiscamt, totaldisc2amt, basesubtotal, basetotaltaxamt, basftotaltaxamt', 'length', 'max' => 19),
            array('reqdate, sodnote, isclosed, ispacked, iscancel', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('sono, sodno, taxid, deptid, srepid, prjid, whid, itemid, pid, itemdesc, qty, unit, conv, qtyx, qtydo, qtyxdo, qtydelivered, qtyxdelivered, qtybo, qtyxbo, cost, listprice, baseprice, discexp, discamt, disc2amt, taxamt, reqdate, sodnote, isclosed, subtotal, taxableamt, totaltaxamt, totaldiscamt, totaldisc2amt, basesubtotal, basetotaltaxamt, basftotaltaxamt, ispacked, iscancel', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'dels' => array(self::HAS_MANY, 'Delid', 'sono'),
            'dels1' => array(self::HAS_MANY, 'Delid', 'sodno'),
            'saleds' => array(self::HAS_MANY, 'Saled', 'sono'),
            'saleds1' => array(self::HAS_MANY, 'Saled', 'sodno'),
            'dept' => array(self::BELONGS_TO, 'Dept', 'deptid'),
            'item' => array(self::BELONGS_TO, 'Item', 'itemid'),
            'prj' => array(self::BELONGS_TO, 'Prj', 'prjid'),
            'so' => array(self::BELONGS_TO, 'So', 'sono'),
            'srep' => array(self::BELONGS_TO, 'Srep', 'srepid'),
            'tax' => array(self::BELONGS_TO, 'Tax', 'taxid'),
            'wh' => array(self::BELONGS_TO, 'Wh', 'whid'),
            'deods' => array(self::HAS_MANY, 'Deod', 'sono'),
            'deods1' => array(self::HAS_MANY, 'Deod', 'sodno'),
            'billso' => array(self::HAS_MANY, 'Billso', 'sono'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'sono' => Yii::t('sod', 'sono'),
            'sodno' => Yii::t('sod', 'sodno'),
            'taxid' => Yii::t('sod', 'taxid'),
            'deptid' => Yii::t('sod', 'deptid'),
            'srepid' => Yii::t('sod', 'srepid'),
            'prjid' => Yii::t('sod', 'prjid'),
            'whid' => Yii::t('sod', 'whid'),
            'itemid' => Yii::t('sod', 'itemid'),
            'pid' => Yii::t('sod', 'pid'),
            'itemdesc' => Yii::t('sod', 'itemdesc'),
            'qty' => Yii::t('sod', 'qty'),
            'unit' => Yii::t('sod', 'unit'),
            'conv' => Yii::t('sod', 'conv'),
            'qtyx' => Yii::t('sod', 'qtyx'),
            'qtydo' => Yii::t('sod', 'qtydo'),
            'qtyxdo' => Yii::t('sod', 'qtyxdo'),
            'qtydelivered' => Yii::t('sod', 'qtydelivered'),
            'qtyxdelivered' => Yii::t('sod', 'qtyxdelivered'),
            'qtybo' => Yii::t('sod', 'qtybo'),
            'qtyxbo' => Yii::t('sod', 'qtyxbo'),
            'cost' => Yii::t('sod', 'cost'),
            'listprice' => Yii::t('sod', 'listprice'),
            'baseprice' => Yii::t('sod', 'baseprice'),
            'discexp' => Yii::t('sod', 'discexp'),
            'discamt' => Yii::t('sod', 'discamt'),
            'disc2amt' => Yii::t('sod', 'disc2amt'),
            'taxamt' => Yii::t('sod', 'taxamt'),
            'reqdate' => Yii::t('sod', 'reqdate'),
            'sodnote' => Yii::t('sod', 'sodnote'),
            'isclosed' => Yii::t('sod', 'isclosed'),
            'subtotal' => Yii::t('sod', 'subtotal'),
            'taxableamt' => Yii::t('sod', 'taxableamt'),
            'totaltaxamt' => Yii::t('sod', 'totaltaxamt'),
            'totaldiscamt' => Yii::t('sod', 'totaldiscamt'),
            'totaldisc2amt' => Yii::t('sod', 'totaldisc2amt'),
            'basesubtotal' => Yii::t('sod', 'basesubtotal'),
            'basetotaltaxamt' => Yii::t('sod', 'basetotaltaxamt'),
            'basftotaltaxamt' => Yii::t('sod', 'basftotaltaxamt'),
            'ispacked' => Yii::t('sod', 'ispacked'),
            'iscancel' => Yii::t('sod', 'iscancel'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('sono', $this->sono, true);
        $criteria->compare('sodno', $this->sodno);
        $criteria->compare('taxid', $this->taxid, true);
        $criteria->compare('deptid', $this->deptid, true);
        $criteria->compare('srepid', $this->srepid, true);
        $criteria->compare('prjid', $this->prjid, true);
        $criteria->compare('whid', $this->whid, true);
        $criteria->compare('itemid', $this->itemid, true);
        $criteria->compare('pid', $this->pid, true);
        $criteria->compare('itemdesc', $this->itemdesc, true);
        $criteria->compare('qty', $this->qty, true);
        $criteria->compare('unit', $this->unit, true);
        $criteria->compare('conv', $this->conv, true);
        $criteria->compare('qtyx', $this->qtyx, true);
        $criteria->compare('qtydo', $this->qtydo, true);
        $criteria->compare('qtyxdo', $this->qtyxdo, true);
        $criteria->compare('qtydelivered', $this->qtydelivered, true);
        $criteria->compare('qtyxdelivered', $this->qtyxdelivered, true);
        $criteria->compare('qtybo', $this->qtybo, true);
        $criteria->compare('qtyxbo', $this->qtyxbo, true);
        $criteria->compare('cost', $this->cost, true);
        $criteria->compare('listprice', $this->listprice, true);
        $criteria->compare('baseprice', $this->baseprice, true);
        $criteria->compare('discexp', $this->discexp, true);
        $criteria->compare('discamt', $this->discamt, true);
        $criteria->compare('disc2amt', $this->disc2amt, true);
        $criteria->compare('taxamt', $this->taxamt, true);
        $criteria->compare('reqdate', $this->reqdate, true);
        $criteria->compare('sodnote', $this->sodnote, true);
        $criteria->compare('isclosed', $this->isclosed);
        $criteria->compare('subtotal', $this->subtotal, true);
        $criteria->compare('taxableamt', $this->taxableamt, true);
        $criteria->compare('totaltaxamt', $this->totaltaxamt, true);
        $criteria->compare('totaldiscamt', $this->totaldiscamt, true);
        $criteria->compare('totaldisc2amt', $this->totaldisc2amt, true);
        $criteria->compare('basesubtotal', $this->basesubtotal, true);
        $criteria->compare('basetotaltaxamt', $this->basetotaltaxamt, true);
        $criteria->compare('basftotaltaxamt', $this->basftotaltaxamt, true);
        $criteria->compare('ispacked', $this->ispacked);
        $criteria->compare('iscancel', $this->iscancel);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }
    
    public function beforeSave() {
        $so = So::model()->findByPk($this->sono);
        if ($this->isNewRecord) {
            $this->srepid = $so->srepid;
            $this->whid = $so->whid;
            $this->listprice = Prc::model()->getPrice1($this->itemid, Bp::model()->getPrcLvlId($so->custid), $so->crcid);
            
            $this->checkItemPromotion($so);
            TransactionCalculator::calcDetailDisc($this);
            $this->setItemTaxID(Bp::model()->getSaleIsTaxed($so->custid));
            TransactionCalculator::calcDetailBasePrice($this, $so->taxinc);
            TransactionCalculator::calcDetailTax($this, $so->taxinc, $so->fisrate, $so->excrate);
            TransactionCalculator::calcDetailSubtotal($this, $so->excrate);
        }

        return true;
    }
    
    public function setItemTaxID($isTaxed) {
        if ($isTaxed) {
            $this->taxid = Item::model()->getSaleTaxID($this->itemid);
        }
    }
    
    public function checkItemPromotion($so) {
        $discexp = Prc::model()->getDiscPromo($this->itemid, $this->qty, $this->unit, $so->sodate, $so->custid, null, Bp::model()->getBPGrpId($so->custid));
        if (!empty($discexp)) {
            $this->discexp = $discexp;
        }

    }

}