<?php

/**
 * This is the model class for table "srep".
 *
 * The followings are the available columns in table 'srep':
 * @property string $srepid
 * @property string $stateid
 * @property string $countryid
 * @property string $cityid
 * @property string $srepname
 * @property string $sreptype
 * @property string $addr
 * @property string $zipcode
 * @property string $phone
 * @property string $mobile
 * @property string $email
 * @property string $status
 * @property string $arlimitamt
 * @property string $passwd
 * @property string $usrid
 *
 * The followings are the available model relations:
 * @property Sod[] $sods
 * @property So[] $sos
 * @property Hostwo[] $hostwos
 * @property Bill[] $bills
 * @property State $state
 * @property Country $country
 * @property City $city
 * @property Sret[] $srets
 * @property Sale[] $sales
 * @property Saled[] $saleds
 * @property Deo[] $deos
 * @property Cret[] $crets
 * @property Cons[] $cons
 * @property Bplog[] $bplogs
 * @property Bp[] $bps
 * @property Usr $usr
 */
class Srep extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Srep the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'srep';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('srepid', 'required'),
            array('srepid, stateid, countryid, usrid', 'length', 'max' => 10),
            array('cityid, sreptype', 'length', 'max' => 5),
            array('srepname, email, passwd', 'length', 'max' => 50),
            array('addr', 'length', 'max' => 255),
            array('zipcode', 'length', 'max' => 6),
            array('phone, mobile', 'length', 'max' => 30),
            array('status', 'length', 'max' => 2),
            array('arlimitamt', 'length', 'max' => 19),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('srepid, stateid, countryid, cityid, srepname, sreptype, addr, zipcode, phone, mobile, email, status, arlimitamt, passwd, usrid', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'sods' => array(self::HAS_MANY, 'Sod', 'srepid'),
            'sos' => array(self::HAS_MANY, 'So', 'srepid'),
            'hostwos' => array(self::HAS_MANY, 'Hostwo', 'srepid'),
            'bills' => array(self::HAS_MANY, 'Bill', 'srepid'),
            'state' => array(self::BELONGS_TO, 'State', 'stateid'),
            'country' => array(self::BELONGS_TO, 'Country', 'countryid'),
            'city' => array(self::BELONGS_TO, 'City', 'cityid'),
            'srets' => array(self::HAS_MANY, 'Sret', 'srepid'),
            'sales' => array(self::HAS_MANY, 'Sale', 'srepid'),
            'saleds' => array(self::HAS_MANY, 'Saled', 'srepid'),
            'deos' => array(self::HAS_MANY, 'Deo', 'srepid'),
            'crets' => array(self::HAS_MANY, 'Cret', 'srepid'),
            'cons' => array(self::HAS_MANY, 'Cons', 'srepid'),
            'bplogs' => array(self::HAS_MANY, 'Bplog', 'srepid'),
            'bps' => array(self::HAS_MANY, 'Bp', 'srepid'),
            'usr' => array(self::BELONGS_TO, 'Usr', 'usrid'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'srepid' => Yii::t('srep', 'srepid'),
            'stateid' => Yii::t('srep', 'stateid'),
            'countryid' => Yii::t('srep', 'countryid'),
            'cityid' => Yii::t('srep', 'cityid'),
            'srepname' => Yii::t('srep', 'srepname'),
            'sreptype' => Yii::t('srep', 'sreptype'),
            'addr' => Yii::t('srep', 'addr'),
            'zipcode' => Yii::t('srep', 'zipcode'),
            'phone' => Yii::t('srep', 'phone'),
            'mobile' => Yii::t('srep', 'mobile'),
            'email' => Yii::t('srep', 'email'),
            'status' => Yii::t('srep', 'status'),
            'arlimitamt' => Yii::t('srep', 'arlimitamt'),
            'passwd' => Yii::t('srep', 'passwd'),
            'usrid' => Yii::t('srep', 'usrid'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('srepid', $this->srepid, true);
        $criteria->compare('stateid', $this->stateid, true);
        $criteria->compare('countryid', $this->countryid, true);
        $criteria->compare('cityid', $this->cityid, true);
        $criteria->compare('srepname', $this->srepname, true);
        $criteria->compare('sreptype', $this->sreptype, true);
        $criteria->compare('addr', $this->addr, true);
        $criteria->compare('zipcode', $this->zipcode, true);
        $criteria->compare('phone', $this->phone, true);
        $criteria->compare('mobile', $this->mobile, true);
        $criteria->compare('email', $this->email, true);
        $criteria->compare('status', $this->status, true);
        $criteria->compare('arlimitamt', $this->arlimitamt, true);
        $criteria->compare('passwd', $this->passwd, true);
        $criteria->compare('usrid', $this->usrid, true);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

}